@@ -1,7 +1,6 @@
 import gi
 gi.require_version("Gtk", "4.0")
 from gi.repository import Gtk,GLib
-import os.path
 
 from . import base
 from . import layout 
@@ -16,9 +15,6 @@ from . import search
 from . import dload
 from . import com
 
-def get_root_file(f):
-	return os.path.join(os.path.dirname(os.path.realpath(__file__)),f)
-
 def quit(widget, mainloop):
 	base.write(widget)
 	daem.close(False)#in base.write is log, can require daemon open
